==> sl-cia-2.0.249.tgz: package/lib/file-system/actual-file.js <==
var fs = require('fs');
var path = require("path");
var consoleFileLogger = require("../sl-logger.js").consoleFileLogger;
var sourceMap = require("source-map");
var globalErrorHandler = require('../global-error-handler');
var sourceRootResolver = require("./source-root-resolver");

function readSourceMaps(fullFilename, logger) {
    if (!fullFilename) return;
    var sourceMapsFilename = fullFilename + '.map';
    var contents, rawSourceMapJsonData, consumer;
    var log = logger ? logger.child({
        methodName: "readSourceMaps"
    }) : consoleFileLogger("readSourceMaps");
    var hasSourceMaps = fs.existsSync(sourceMapsFilename);
    if(!hasSourceMaps){
        return null;
    }
    try {
        contents = fs.readFileSync(sourceMapsFilename).toString();
    }catch (e) {
        log.warn("failed to read sourcemap file content. " +e);
        return null;
    }

    try {
        rawSourceMapJsonData = JSON.parse(contents);
    } catch (e) {
        globalErrorHandler.setLastError(e);
        return null;
    }

    try {
        log.debug('Processing source maps from file: ' + sourceMapsFilename);
        consumer = new sourceMap.SourceMapConsumer(rawSourceMapJsonData);
        tryOverridePathInSourceMap(consumer, fullFilename, logger)
                
        return consumer;
    } catch (e) {
        if(e instanceof SourceMapError){throw e}
        globalErrorHandler.setLastError(e);
        return null;
    }
}

/**
 * By default, source maps store relative path to the file.
 * This methods try to convert the path to an absolute path for easier processing
 * later in the build process.
 */
function tryOverridePathInSourceMap(consumer, fullFilename, logger){
    if (!consumer || !consumer.sources || consumer.sources.length == 0){
        return;
    }

    var log = logger ? logger.child({
        methodName: "tryOverridePathInSourceMap"
    }) : consoleFileLogger("tryOverridePathInSourceMap");

    var parsedPath = path.parse(fullFilename);
    var newSources = [];
    for (var i=0; i < consumer.sources.length; i++){
        var sourceFile =  consumer["_sources"]["_array"][i];
        var absolutePath = "";
        if (path.isAbsolute(sourceFile)){
            absolutePath = sourceFile
        }else {

            var sourceRoot = sourceRootResolver.resolveSourceRoot(sourceFile, parsedPath.dir, log);
            sourceFile = sourceFile.replace(/\.\.\//g, "");  //Since we have the source root, we don't need relative path.
            absolutePath = path.join(sourceRoot, sourceFile);
        }

        log.debug("Path '" + consumer.sources[i] + "' is overridden to '" + absolutePath+ "'.")
        newSources.push(absolutePath);
    }
    
    consumer["_sources"]["_array"] = newSources;

    if (consumer.sources.length > 1){
        log.warn("File '" + fullFilename+ "' has multiple sources. An assumption is made that they all originate can be found in folder '" + parsedPath.dir + "'.");
    }
}

function ActualFile(filename, fullFilename) {
    this.getFilename = function ActualFile$getFilename() {
        return filename;
    }
    this.getFullFilename = function ActualFile$getFullFilename() {
        return fullFilename;
    }
    this.getContent = function ActualFile$getContent() {
        var content = fs.readFileSync(fullFilename, 'utf-8');
        return content;
    }
    this.readSourceMaps = function ActualFile$readSourceMaps(logger) {
        return readSourceMaps(fullFilename, logger);
    }
}
module.exports = ActualFile;

==> sl-cia-2.0.262.tgz: package/lib/file-system/actual-file.js <==
var fs = require('fs');
var path = require("path");
var consoleFileLogger = require("../sl-logger.js").consoleFileLogger;
var sourceMap = require("source-map");
var globalErrorHandler = require('../global-error-handler');
var sourceRootResolver = require("./source-root-resolver");
var fileAndFolderUtils = require('../file-and-folder-utils');

function readSourceMaps(fullFilename, logger) {
    if (!fullFilename) return;
    var sourceMapsFilename = fullFilename + '.map';
    var contents, rawSourceMapJsonData, consumer;
    var log = logger ? logger.child({
        methodName: "readSourceMaps"
    }) : consoleFileLogger("readSourceMaps");
    var hasSourceMaps = fs.existsSync(sourceMapsFilename);
    if(!hasSourceMaps){
        return null;
    }
    try {
        contents = fs.readFileSync(sourceMapsFilename).toString();
    }catch (e) {
        log.warn("failed to read sourcemap file content. " +e);
        return null;
    }

    try {
        rawSourceMapJsonData = JSON.parse(contents);
    } catch (e) {
        globalErrorHandler.setLastError(e);
        return null;
    }

    try {
        log.debug('Processing source maps from file: ' + sourceMapsFilename);
        consumer = new sourceMap.SourceMapConsumer(rawSourceMapJsonData);
        tryOverridePathInSourceMap(consumer, fullFilename, logger)
                
        return consumer;
    } catch (e) {
        globalErrorHandler.setLastError(e);
        return null;
    }
}

/**
 * By default, source maps store relative path to the file.
 * This methods try to convert the path to an absolute path for easier processing
 * later in the build process.
 */
function tryOverridePathInSourceMap(consumer, fullFilename, logger){
    if (!consumer || !consumer.sources || consumer.sources.length == 0){
        return;
    }

    var log = logger ? logger.child({
        methodName: "tryOverridePathInSourceMap"
    }) : consoleFileLogger("tryOverridePathInSourceMap");

    var parsedPath = path.parse(fullFilename);
    var newSources = [];

    for (var i=0; i < consumer.sources.length; i++){
        var sourceFile =  consumer["_sources"]["_array"][i];
        var absolutePath = "";
        if (path.isAbsolute(sourceFile)){
            absolutePath = sourceFile;
            if (!sourceRootResolver.isResolved) {
                log.debug("Source map path's are absolute, considering source root as resolved.");
                sourceRootResolver.isResolved = true;
            }
        }else {
            var sourceRoot = sourceRootResolver.resolveSourceRoot(sourceFile, parsedPath.dir, log);
            sourceFile = fileAndFolderUtils.removeRelativeSigns(sourceFile);
            absolutePath = path.join(sourceRoot, sourceFile);
        }

        log.debug("Path '" + sourceFile + "' is overridden to '" + absolutePath+ "'.");
        newSources.push(absolutePath);
    }
    
    consumer["_sources"]["_array"] = newSources;

    if (consumer.sources.length > 1){
        log.warn("File '" + fullFilename+ "' has multiple sources. An assumption is made that they all originate can be found in folder '" + parsedPath.dir + "'.");
    }
}

function ActualFile(filename, fullFilename) {
    this.getFilename = function ActualFile$getFilename() {
        return filename;
    }
    this.getFullFilename = function ActualFile$getFullFilename() {
        return fullFilename;
    }
    this.getContent = function ActualFile$getContent() {
        var content = fs.readFileSync(fullFilename, 'utf-8');
        return content;
    }
    this.readSourceMaps = function ActualFile$readSourceMaps(logger) {
        return readSourceMaps(fullFilename, logger);
    }
}
module.exports = ActualFile;
